==> als-structure_2.12-3.0.1-sources.jar: org/mulesoft/language/outline/structure/structureImpl/factory/webapi/AmfBuilderFactory.scala <==
package org.mulesoft.language.outline.structure.structureImpl.factory.webapi

import org.mulesoft.language.outline.structure.structureImpl.BuilderFactory
import org.mulesoft.language.outline.structure.structureImpl.companion.FieldCompanionList
import org.mulesoft.language.outline.structure.structureImpl.symbol.corebuilders._
import org.mulesoft.language.outline.structure.structureImpl.symbol.webapibuilders._
import org.mulesoft.language.outline.structure.structureImpl.symbol.webapibuilders.fields._

trait AmfBuilderFactory extends BuilderFactory {

  override protected def companion: FieldCompanionList =
    super.companion +
      DefaultWebApiArrayFieldTypeSymbolBuilderCompanion +
      DefaultWebApiScalarTypeSymbolBuilderCompanion +
      HeadersSymbolBuilder +
      QueryParametersSymbolBuilder +
      QueryStringSymbolBuilder +
      UriParametersSymbolBuilder +
      ExampleSymbolBuilders +
      DomainExtensionSymbolBuilder +
      ObjectNodeSymbolBuilder +
      PropertyShapeSymbolBuilder +
      OperationSymbolBuilderCompanion +
      OperationsArrayFieldBuilderCompanion +
      ParameterSymbolBuilderCompanion +
      PayloadSymbolBuilderCompanion +
      CustomDomainPropertySymbolBuilderCompanion +
      PayloadsArrayFieldBuilderCompanion +
      EndPointFieldBuilderCompanion +
      WebApiEncodesFieldSymbolBuilderCompanion +
      LicenseFieldSymbolBuilderCompanion +
      ContactFieldSymbolBuilderCompanion +
      ContentTypeIgnoredFieldBuilderCompanion +
      AcceptsIgnoredFieldBuilderCompanion +
      RequestSymbolBuilderCompanion +
      RequestArrayFieldSymbolBuilderCompanion +
      ShapeInheritsArrayFieldBuilderCompanion +
      ExampleArrayFieldCompanion +
      TagsArrayFieldSymbolBuilderCompanion +
      ProtocolsArrayFieldBuilderCompanion +
      ServerSymbolBuilderCompanion +
      PayloadFieldSymbolCompanion +
      ParameterLinksArrayFieldSymbolBuilderCompanion
}

==> als-structure_2.12-3.2.1-0-sources.jar: org/mulesoft/language/outline/structure/structureImpl/factory/webapi/AmfBuilderFactory.scala <==
package org.mulesoft.language.outline.structure.structureImpl.factory.webapi

import org.mulesoft.language.outline.structure.structureImpl.BuilderFactory
import org.mulesoft.language.outline.structure.structureImpl.companion.FieldCompanionList
import org.mulesoft.language.outline.structure.structureImpl.symbol.corebuilders._
import org.mulesoft.language.outline.structure.structureImpl.symbol.webapibuilders._
import org.mulesoft.language.outline.structure.structureImpl.symbol.webapibuilders.fields._
import org.mulesoft.language.outline.structure.structureImpl.symbol.webapibuilders.ramlbuilders.RamlSecuritySchemeSettingsFieldSymbolBuilderCompanion

trait AmfBuilderFactory extends BuilderFactory {

  override protected def companion: FieldCompanionList =
    super.companion +
      DefaultWebApiArrayFieldTypeSymbolBuilderCompanion +
      DefaultWebApiScalarTypeSymbolBuilderCompanion +
      HeadersSymbolBuilder +
      QueryParametersSymbolBuilder +
      QueryStringSymbolBuilder +
      UriParametersSymbolBuilder +
      ExampleSymbolBuilders +
      DomainExtensionSymbolBuilder +
      ObjectNodeSymbolBuilder +
      PropertyShapeSymbolBuilder +
      OperationSymbolBuilderCompanion +
      OperationsArrayFieldBuilderCompanion +
      ParameterSymbolBuilderCompanion +
      PayloadSymbolBuilderCompanion +
      CustomDomainPropertySymbolBuilderCompanion +
      PayloadsArrayFieldBuilderCompanion +
      EndPointFieldBuilderCompanion +
      WebApiEncodesFieldSymbolBuilderCompanion +
      LicenseFieldSymbolBuilderCompanion +
      ContactFieldSymbolBuilderCompanion +
      ContentTypeIgnoredFieldBuilderCompanion +
      AcceptsIgnoredFieldBuilderCompanion +
      RequestSymbolBuilderCompanion +
      RequestArrayFieldSymbolBuilderCompanion +
      ShapeInheritsArrayFieldBuilderCompanion +
      ExampleArrayFieldCompanion +
      TagsArrayFieldSymbolBuilderCompanion +
      ProtocolsArrayFieldBuilderCompanion +
      ServerSymbolBuilderCompanion +
      PayloadFieldSymbolCompanion +
      ParameterLinksArrayFieldSymbolBuilderCompanion
}
